/*
 * To change this license header, choose License Headers in Project Properties.
 * To change this template file, choose Tools | Templates
 * and open the template in the editor.
 */
package com.ryuuji.servlet.apoderado;

import java.io.IOException;
import java.io.PrintWriter;
import javax.servlet.ServletException;
import javax.servlet.annotation.WebServlet;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import logica.ExNihilo;
import logica.Search;
import logica.Utilities;
import orm.Colegio;

/**
 *
 * @author ryuuji
 */
@WebServlet(name = "CrearApoderado", urlPatterns = {"/CrearApoderado"})
public class CrearApoderado extends HttpServlet {

    /**
     * Processes requests for both HTTP <code>GET</code> and <code>POST</code> methods.
     *
     * @param request servlet request
     * @param response servlet response
     * @throws ServletException if a servlet-specific error occurs
     * @throws IOException if an I/O error occurs
     */
    protected void processRequest(HttpServletRequest request, HttpServletResponse response)
            throws ServletException, IOException {

        response.setContentType("text/html;charset=UTF-8");
        String nombre = request.getParameter("nombre");
        String rut = request.getParameter("rut");
        String id = request.getParameter("id");

        if (!nombre.equals("")) {
            if (!rut.equals("")) {
                if (!id.equals("")) {
                    if (Utilities.validarRut(rut, id)) {
                        if (Search.buscarProfesor(rut + id) == null && Search.buscarApoderado(rut + id) == null && Search.buscarEstudiante(rut + id) == null) {
                            if (Search.buscarApoderado(rut + id) == null) {
                                Colegio colegio = Search.buscarColegio("Colegio San Francisco");
                                if (colegio != null) {
                                    if (ExNihilo.crearApoderado(Search.buscarColegio("Colegio San Francisco"), nombre, rut + id)) {
                                        request.getRequestDispatcher("ApoderadosServlet").forward(request, response);
                                    } else {
                                        request.setAttribute("errorCrear", "A ocurrido un error innesperado");
                                        request.getRequestDispatcher("ApoderadosServlet").forward(request, response);
                                    }
                                } else {
                                    if (ExNihilo.crearColegio("Colegio San Francisco")) {
                                        if (ExNihilo.crearApoderado(Search.buscarColegio("Colegio San Francisco"), nombre, rut + id)) {
                                            request.getRequestDispatcher("ApoderadosServlet").forward(request, response);
                                        } else {
                                            request.setAttribute("errorCrear", "A ocurrido un error innesperado");
                                            request.getRequestDispatcher("ApoderadosServlet").forward(request, response);
                                        }
                                    } else {
                                        request.setAttribute("errorCrear", "A ocurrido un error innesperado");
                                        request.getRequestDispatcher("ApoderadosServlet").forward(request, response);
                                    }
                                }
                            } else {
                                request.setAttribute("errorCrear", "Ya existe el apoderado");
                                request.getRequestDispatcher("ApoderadosServlet").forward(request, response);
                            }
                        } else {
                            request.setAttribute("errorCrear", "Ya hay alguien con ese rut");
                            request.getRequestDispatcher("ApoderadosServlet").forward(request, response);
                        }
                    } else {
                        request.setAttribute("errorCrear", "El rut no es valido");
                        request.getRequestDispatcher("ApoderadosServlet").forward(request, response);
                    }
                } else {
                    request.setAttribute("errorCrear", "Debe ingresar el codigo verificador");
                    request.getRequestDispatcher("ApoderadosServlet").forward(request, response);
                }
            } else {
                request.setAttribute("errorCrear", "Debe ingresar un rut");
                request.getRequestDispatcher("ApoderadosServlet").forward(request, response);
            }
        } else {
            request.setAttribute("errorCrear", "Debe ingresar un rut");
            request.getRequestDispatcher("ApoderadosServlet").forward(request, response);
        }
    }

    // <editor-fold defaultstate="collapsed" desc="HttpServlet methods. Click on the + sign on the left to edit the code.">
    /**
     * Handles the HTTP <code>GET</code> method.
     *
     * @param request servlet request
     * @param response servlet response
     * @throws ServletException if a servlet-specific error occurs
     * @throws IOException if an I/O error occurs
     */
    @Override
    protected void doGet(HttpServletRequest request, HttpServletResponse response)
            throws ServletException, IOException {
        processRequest(request, response);
    }

    /**
     * Handles the HTTP <code>POST</code> method.
     *
     * @param request servlet request
     * @param response servlet response
     * @throws ServletException if a servlet-specific error occurs
     * @throws IOException if an I/O error occurs
     */
    @Override
    protected void doPost(HttpServletRequest request, HttpServletResponse response)
            throws ServletException, IOException {
        processRequest(request, response);
    }

    /**
     * Returns a short description of the servlet.
     *
     * @return a String containing servlet description
     */
    @Override
    public String getServletInfo() {
        return "Short description";
    }// </editor-fold>

}
